Composition
===========

*Subclasses*

.. toctree::
   :maxdepth: 1

   AutodiffComposition
   CompositionFunctionApproximator
|
*Related*

* `NodeRoles <NodeRole>`

.. toctree::
   :maxdepth: 1

   Pathway
   Scheduling
|
.. automodule:: psyneulink.core.compositions.composition
   :members: Composition, NodeRole
   :exclude-members: Parameters, show_structure, CompositionError
